@@ -220,7 +220,7 @@ class MarketAnalyzer:
 
 
 
-    def get_kpi(self):
+    def get_kpi(self, drop_duplicate=True):
         """ Compute some key performance indicators and set them in a table.
 
         Returns
@@ -248,7 +248,14 @@ class MarketAnalyzer:
             i += 1
 
         # return set_table(results, self.assets, self.metrics)
-        return pd.DataFrame(results, columns=self.assets, index=self.metrics)
+        kpis_df = pd.DataFrame(results, columns=self.assets, index=self.metrics)
+        # return set_table(results, self.assets, self.metrics)
+        if drop_duplicate:
+            print('dropping duplicate')
+            #_, indices = np.unique(results, axis=1, return_index=True)
+            kpis_df = kpis_df.T.drop_duplicates().T
+
+        return kpis_df
 
     def display_kpi(self, title='KPI table'):
         """ Display KPI. """
