@@ -93,7 +93,7 @@ class NaPoleonBinanceFutureBot(object):
         while not  position_changed:
             if counter>1:
                 print(f'position not reached : reupdating positions {positions}')
-            self.cancel_all_order()
+            self.cancel_all_orders()
             position_changed = self.change_position(positions)
             # Prints the current time with a five second difference
             print(f'waiting for the oder to be filled {sleeping_time}')
