@@ -227,6 +227,24 @@ def generate_fourier_decomposition(lookback_windows,contravariants,n_harms,fft_f
                         })
     return parameters
 
+def generate_rooftingFilter(lookback_windows, periods, n_harms, fft_filter_types, contravariants):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for period in periods:
+            for n_harm in n_harms:
+                for fft_filter_type in fft_filter_types:
+                    for contravariant in contravariants:
+                        if period < lookback_window:
+                            parameters.append({
+                                'lookback_window': lookback_window,
+                                'period':period,
+                                'n_harm':n_harm,
+                                'fft_filter_type':fft_filter_type,
+                                'contravariant':contravariant
+                            })
+    return parameters
+
+
 def generate_lookback_contravariant(lookback_windows, contravariants):
     parameters = []
     for lookback_window in lookback_windows:
