@@ -533,8 +533,7 @@ def discretize_two_states(y_pred, splitting_quantile_threshold=0.5):
     try:
         threshold = np.quantile(y_pred, splitting_quantile_threshold)
     except Exception as e:
-        print(e)
-        print("the quantile could not get computed")
+        threshold = 0.5
     if np.isnan(threshold) :
         threshold = 0.5
     y_pred_discrete[y_pred > threshold] = 1.
@@ -575,8 +574,8 @@ def find_best_two_states_discretization(y_pred, y, seed = 42, number_per_year =
         trouble = True
         ## we do nothting
         #print(e)
-
-
+    if np.isnan(splitting_quantile_threshold):
+        splitting_quantile_threshold = 0.5
 
     y_pred_discrete = discretize_two_states(y_pred, splitting_quantile_threshold=splitting_quantile_threshold)
     perf_df = signal_utility.reconstitute_prediction_perf(y_pred=y_pred_discrete, y_true=y,
@@ -585,7 +584,7 @@ def find_best_two_states_discretization(y_pred, y, seed = 42, number_per_year =
     sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
     sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=number_per_year, from_ret=True)
     print('computing threshold value from quantile '+str(splitting_quantile_threshold))
-    print('computing threshold value with length '+len(y_pred))
+    print('computing threshold value with length '+str(len(y_pred)))
     splitting_threshold = np.quantile(y_pred, splitting_quantile_threshold)
     return splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under
 
